@@ -90,7 +90,7 @@ kableExtra::kable_styling(knitr::kable(mydfMarkColor) , full_width = F
 mydfOfMarks<-read.table(text=
 "            OTU chrName markName chrRegion markSize markDistCen
 \"Species one\"      1      45S       p       NA         NA     # no measure means whole arm
-\"Species one\"      1       5S       q        1         0.5
+\"Species one\"      1       5S       q      0.5         0.5
 \"Species one\"      B  \"B mark\"    w       NA         NA     # w for whole chromosome
 \"Species one\"      2     45S        p        1         1.0
 \"Species one\"      3     DAPI       q        1         1.0
@@ -112,85 +112,70 @@ notesdf<-read.table(text=
 "            OTU    note
 \"Species one\"   \"Author notes\"  ", header=TRUE, stringsAsFactors=FALSE,fill=TRUE)
 
-## ----example_M1, echo=TRUE, results="hide", fig.width=7, fig.height=4.5, message=FALSE,dev='svg'----
-# fig.width=7, fig.height=4.5
-
-svg("mydfChrSize.svg",width=13,height=8 )
+## ----example_M1, echo=TRUE, results="hide", fig.width=13, fig.height=8, message=FALSE, dev='png'----
+# svg("mydfChrSize.svg",width=13,height=8 )
 # png("mydfChrSize.png", width=600, height=400)
-plotIdiograms(dfChrSize= mydfChrSize,     # chr. size data.frame
-              dfMarkPos= mydfOfMarks,     # mark position df (inc. cen.)
 
-              dfMarkColor=mydfMarkColor,  # mark style df
+# par(mar = c(0, 0, 0, 0), omi=rep(0,4), oma=rep(0,4) )
+
+plotIdiograms(dfChrSize= mydfChrSize,     # chr. size data.frame
+              dfMarkPos= mydfOfMarks,     # mark position data.frame (inc. cen.)
+              dfMarkColor=mydfMarkColor,  # mark style d.f.
               roundness=3,                # vertices roundness  
-              dotRoundCorr=2.5,           # correction of roundness of dots 
-              
+              distTextChr = .7,           # separation among text and chr names and ind.              
               orderBySize = FALSE,        # do not order chr. by size
-              chrWidth=4.5,               # width of chr.
-              chrSpacing = 4,             # space among chr.
               karHeiSpace=1.6,            # vertical size of karyotype including spacer
               
-              indexIdTextSize=1,          # font size fo chr name and indices
-              OTUTextSize=1.2,            # font size of OTUs
-              markLabelSize=1,            # font size of mark legends
-              
-              rulerPos=-1.9,              # ruler position
-              ruler.tck=-0.02,            # ticks of ruler size and orientation
-              rulerNumberPos=.5,          # position of numbers in ruler
-              rulerNumberSize=1,          # font size of ruler numbers
-              
-              ylimBotMod = 0.4,           # modify ylim bottom argument
-              ylimTopMod = 0              # modify ylim top argument
-              
-              ,notes=notesdf              # data.frame with notes NEW
-              ,notesTextSize = 1.3        # font size of notes
-              ,notesPos = 1.5             # space from chr. (right) to note
-              
-              ,xlimRightMod = 12          # modify right xlim
-              ,legend="aside"             # position of legend
-              ,legendWidth = .5           # legend item width
+              legendWidth = .8            # legend item width
               ,legendHeight = .5          # legend item height
-              ,markLabelSpacer = 8        # legend spacer
+              ,markLabelSpacer = 2        # legend spacer
+              
+              ,rulerPos=-1,               # ruler position
+              ruler.tck=-0.01,            # ticks of ruler size and orientation
+              
+              notes=notesdf               # data.frame with notes NEW
+              ,notesTextSize = 1.3        # font size of notes
+              ,notesPos = .2              # space from chr. (right) to note
+              
+              ,ylimBotMod = 0.4           # modify ylim bottom argument
+              ,ylimTopMod = 0             # modify ylim top argument
+              ,xlimLeftMod = 2            # modify left xlim
+              ,xlimRightMod = 3           # modify right xlim
+              ,asp=1                      # y x aspect ratio
+
 )
-dev.off()
+# dev.off()
 
 ## ---- results="asis", comment=NA, echo=FALSE-----------------------------
 # cat(paste0("![](mydfChrSize.png)" ) )
-cat(paste0("![](mydfChrSize.svg)" ) )
+# cat(paste0("![](mydfChrSize.svg)" ) )
 
-## ----example_M1cen0, echo=TRUE, results="hide", fig.width=7, fig.height=4.5, message=FALSE,dev='svg'----
+## ----example_M1cen0, echo=TRUE, results="hide", fig.width=7, fig.height=4.5, message=FALSE,dev='png'----
 
-png("mydfChrSize2.png", width=800, height=950)
+png("mydfChrSize2.png", width=700, height=950)
 plotIdiograms(dfChrSize   = bigdfOfChrSize[1:14,],  # chr. size df
               dfMarkColor = mydfMarkColor,# mark style df
-              dfMarkPos   = bigdfOfMarks,  # mark position df
+              dfMarkPos   = bigdfOfMarks, # mark position df
               
               # cen. marks NOT AVAILABLE for centromereSize = 0
               centromereSize = 0,         # <- HERE
-              amoSepar = 0.8,             # separ. among kar.
-              
-              roundness=2,                # vertices roundness  
-              dotRoundCorr=1.0,           # correction of roundness of dots 
-              
-              chrWidth=4,                 # width of chr.
-              chrSpacing = 4,             # space among chr.
-              karHeiSpace=2,              # vertical size of karyotype including spacer
-              indexIdTextSize=1,          # font size fo chr name and indices
-              OTUTextSize    =1,          # font size of OTUs
+              roundness=3,                # vertices roundness  
+              chrSpacing = .7,            # space among chr.
+              karHeight = 3,              # karyotype rel. height 
+              karHeiSpace=5,              # vertical size of karyotype including spacer
+              amoSepar= 2.5,              # separation among karyotype
+              indexIdTextSize=.8,         # font size fo chr name and indices
+              karIndexPos = .1,           # position of kar. index
               markLabelSize=.7,           # font size of mark legends
-              distTextChr = .2,
+              distTextChr = .8,           # separation among chr. and ind.
               
-              rulerPos=-1.9,              # ruler position
+              rulerPos=-.8,               # ruler position
               ruler.tck=-0.01,            # ticks of ruler size and orientation
-              rulerNumberPos=.5,          # position of numbers in ruler
-              rulerNumberSize=1,          # font size of ruler numbers
               
+              xlimLeftMod = 2,            # modify xlim left argument 
               ylimBotMod = 0.4,           # modify ylim bottom argument
               ylimTopMod = 0              # modify ylim top argument
-              
-              # ,markLabelSpacer=5
-              # ,xlimRightMod = 16        #   TRY THIS
-              # ,legend="aside"
-              # ,legendWidth = 1.5
+              ,asp=1                      # y x aspect
 )
 dev.off()
 
@@ -213,18 +198,15 @@ cat(paste0("![](mydfChrSize2.png)" ) )
 #  
 #                mycolors = charVectorCol,    # colors to use
 #  
-#                OTUTextSize = 1,             # font size for OTU names
-#                dotRoundCorr=2,              # correction of roundness of vert. and dots
-#                chrWidth=2.5,                # rel. chr. width
-#                chrSpacing = 2.5,            # rel. horizontal chr. spacing
-#                karHeiSpace=1.6,             # karyotype height including spacing
-#                indexIdTextSize=1,           # font size for chr. indexes and chr. name
-#                markLabelSize=1,             # font size for labels (legend)
+#                distTextChr = .5             # separ. text and chr.
+#                ,karHeiSpace=1.6,            # karyotype height including spacing
+#                markLabelSize=.7,            # font size for labels (legend)
 #  
-#                rulerPos=-1.9,               # ruler position
-#                ruler.tck=-0.02,             # ruler tick orientation and length
-#                rulerNumberPos=.5,           # rulers' numbers position
-#                rulerNumberSize=1            # ruler font size
+#                rulerPos=-.5,                # ruler position
+#                ruler.tck=-0.01,             # ruler tick orientation and length
+#                rulerNumberSize=.5           # ruler font size
+#                ,asp=1                       # y x aspect
+#                ,xlimRightMod = 1            # modify xlim right arg.
 #  )
 #  dev.off()
 
@@ -232,15 +214,11 @@ cat(paste0("![](mydfChrSize2.png)" ) )
 #  head(bigdfOfChrSize,30)
 
 ## ---- echo=F-------------------------------------------------------------
-# kableExtra::scroll_box(height = "300px", width="400px",
-           # kableExtra::add_header_above(
-                            kableExtra::kable_styling(knitr::kable(head(bigdfOfChrSize,30)) , full_width = F
+kableExtra::kable_styling(knitr::kable(head(bigdfOfChrSize,30)) , full_width = F
                            , font_size = 10
                           , bootstrap_options = c("striped", "hover", "condensed"),
                  
 ) 
-# ) 
-# )
 
 ## ---- width=45-----------------------------------------------------------
 data("dfMarkColor")
@@ -266,23 +244,20 @@ kableExtra::kable_styling(knitr::kable(bigdfOfMarks) , full_width = F
 plotIdiograms(dfChrSize  =bigdfOfChrSize,# chr sizes
               dfMarkColor=dfMarkColor,   # mark characteristics, optional in dev version. see above. 
               dfMarkPos  =bigdfOfMarks,  # mark positions (inc. cen. marks)
-                                         # cen. marks in bigdfOfMarks
-              karHeight=1.2,             # karyotype rel. height
-              karHeiSpace=2.2,           # karyotype vertical size with spacing
-              karSepar = TRUE,           # modify vertical separation of kar.
-              amoSepar = 1.2,            # Vertical separation of kar. when karSpear = TRUE
+              # cen. marks in bigdfOfMarks
+
+              karHeight=2.5,             # karyotype rel. height
+              karHeiSpace=6,             # karyotype vertical size with spacing
+              amoSepar = 2,              # Vertical separation of kar. when karSpear = TRUE
               
               centromereSize = 1,        # apparent size of cen.
               roundness = 10,            # roundness of chr. vertices
-              dotRoundCorr = .5,         # correction factor for dot marks and vertices
-              distTextChr=.5,            # distance of chr. to text
+              distTextChr=.8,            # distance of chr. to text
               morpho=FALSE,              # add chr. morphology
               indexIdTextSize=.6,        # font size of indices and chr. name
               OTUTextSize=.9,            # font size of OTU names
               
-              legend="aside",            # position of legend not "inline"
               markLabelSize=.7,          # font size of legend
-              markLabelSpacer=1,         # distance from chr. to legend
               legendHeight = 2,          # height of labels
               
               ruler=TRUE,                # add ruler
@@ -291,11 +266,13 @@ plotIdiograms(dfChrSize  =bigdfOfChrSize,# chr sizes
               ruler.tck=-0.004,          # size and orient. of ticks in ruler
               rulerNumberPos=.4,         # position of numbers of ruler
               rulerNumberSize=.4,        # font size of ruler
-              
-              xlimRightMod=2,            # modify xlim right argument
+
+              xlimRightMod = 3,          # modify xlim left argument 
               ylimBotMod = 0,            # modify ylim bottom argument
               ylimTopMod = -.3           # modify ylim top argument
-              )
+              ,asp=1                     # y x aspect ratio
+)
+
 # dev.off() # for png()
 
 ## ---- results="asis", comment=NA, echo=FALSE, eval=FALSE-----------------
@@ -326,33 +303,88 @@ notesdf2<-read.table(text=
 \"Allopolyploid\"  Allopolyploid  ", header=TRUE, stringsAsFactors=FALSE,fill=TRUE)
 
 ## ---- echo=TRUE, results="hide", fig.width=7, fig.height=9, message=FALSE,dev='png'----
-# fig.width=7, fig.height=4.5
 
 # svg("gish.svg",width=7,height=9 )
 # png("mydfChrSize.png", width=700, height=900)
 plotIdiograms(dfChrSize = parentalAndHybChrSize,  # d.f. of chr. sizes
               dfMarkPos = dfAlloParentMarks,      # d.f. of marks' positions
-              chrColor  = "gray",          # chr. color
-              cenColor  = NULL,            # cen. color when GISH
-
-              OTUTextSize = 1,             # font size for OTU names
-              dotRoundCorr=2,              # correction of roundness of vert. and dots
-              chrWidth=2.5,                # rel. chr. width
-              chrSpacing = 2.5,            # rel. horizontal chr. spacing
-              karHeiSpace=2,               # karyotype height including spacing
-              indexIdTextSize=0.7,         # font size for chr. indexes and chr. name
-              markLabelSize=1,             # font size for labels (legend)
-              distTextChr = 0.3,
-
-              rulerPos=-1.9,               # ruler position
-              ruler.tck=-0.02,             # ruler tick orientation and length
-              rulerNumberPos=.5,           # rulers' numbers position
-              rulerNumberSize=0.5          # ruler font size
+              cenColor  = NULL,            # cen. color 
+              
+              karHeiSpace=5,               # karyotype height including spacing
+              karSepar = FALSE,            # equally sized (height) karyotypes
+              
+              rulerPos=-1.2,               # ruler position
+              ruler.tck= -0.006,           # ruler tick orientation and length
+              rulerNumberSize=.4           # ruler font size
+              
               ,legend=""                   # no legend
+              ,asp=1                       # y x aspect ratio
               
               ,notes=notesdf2              # data.frame with notes NEW
               ,notesTextSize = 1.3         # font size of notes
               ,notesPos = 1.5              # space from chr. (right) to note
+              
+              ,ylimBotMod = 1              # ylim bottom argument mod.
 )
 # dev.off()
 
+## ---- echo=TRUE, results="hide", fig.width=10, fig.height=14, message=FALSE,dev='png', warning=FALSE----
+
+# merge data.frames in micrometers and number of bases
+mixedThreeSpChrSize <- plyr::rbind.fill(bigdfOfChrSize[1:14,], bigdfOfChrSize3Mb)
+# sort by OTU name
+mixedThreeSpChrSize <- mixedThreeSpChrSize[order(mixedThreeSpChrSize$OTU),]
+ 
+# merge marks in micrometers and bases
+mixedThreeSpMarks <- plyr::rbind.fill(bigdfOfMarks , bigdfOfMarks3Mb)
+
+plotIdiograms(dfChrSize   = mixedThreeSpChrSize,  # chr. size df
+              dfMarkPos   = mixedThreeSpMarks,    # mark position df
+              centromereSize = 1,         # cen. size
+              amoSepar = 0.8,             # separ. among kar.
+              
+              roundness=5,                # vertices roundness
+              
+              chrWidth=.3,                # width of chr.
+              chrSpacing = .3,            # space among chr.
+              kerHeight=3,                # karyotype height without spacing
+              karHeiSpace = 3.5,          # vertical size of karyotype including spacer
+              indexIdTextSize=.7,         # font size fo chr name and indices
+              markLabelSize=.7,           # font size of mark legends
+              distTextChr = .55,          # separation among chr. names and indices
+              
+              legendWidth = 1.5           # legend items width
+              ,ylabline = -7              # position of Mb (title) in axis               
+              
+              ,rulerPos=-.5,              # ruler position
+              ruler.tck=-0.01,            # ticks of ruler size and orientation
+              rulerNumberPos =.7,         # position of numbers in ruler
+              rulerNumberSize=.5,         # font size of ruler numbers
+              
+              ylimBotMod = 0.4,           # modify ylim bottom argument
+              ylimTopMod = 0              # modify ylim top argument
+              ,asp=1                      # aspect of plot
+)
+
+## ---- eval=F-------------------------------------------------------------
+#  head(mixedThreeSpChrSize,6)
+
+## ---- echo=F-------------------------------------------------------------
+kableExtra::kable_styling(knitr::kable(head(mixedThreeSpChrSize,6)) , full_width = F
+                           , font_size = 10
+                          , bootstrap_options = c("striped", "hover", "condensed"),
+                 
+) 
+
+## ---- eval=F-------------------------------------------------------------
+#  mixedThreeSpMarks[which(mixedThreeSpMarks$OTU %in% c("Species 1","Species 1 genome") ),]
+
+## ---- echo=F-------------------------------------------------------------
+options("scipen"=10)  
+kableExtra::kable_styling(knitr::kable(mixedThreeSpMarks[which(mixedThreeSpMarks$OTU %in% c("Species 1","Species 1 genome") ),] 
+ ) , full_width = F
+                           , font_size = 10
+                          , bootstrap_options = c("striped", "hover", "condensed"),
+                 
+) 
+
