@@ -56,25 +56,18 @@ plotIdiograms(dfChrSize=dfwithgroups, # chr sizes
               orderBySize = TRUE,     # order chr. by size
               chrColor = "gray",      # chr. color  
               cenColor = "gray",      # centromere color
-              chrWidth=2.5,           # chromosome width
-              chrSpacing = 2.5,       # space among chromosomes
-              karHeiSpace=1,          # vertical size of karyotypes
-              karHeight = 1,          # vertical size of karyotypes including spacing
               
-              distTextChr = 0.6,      # distance from chr. to its name
               chrId="original",       # chr. names as in you data.frame
-              indexIdTextSize=1,      # font size of chr. name and indices
               chrIndex = FALSE,       # do not add chr. indices 
               morpho=FALSE,           # do not add chr. morphology
               karIndex = FALSE,       # do not add karyotype indices
               
-              rulerPos=-2.2,          # position of ruler
-              ruler.tck=-0.02,        # size and orientation of tick of ruler
-              rulerNumberPos=.5,      # position of numbers of ruler
+              rulerPos=-.5,           # position of ruler
               rulerNumberSize=.7,     # font size of ruler
-
+              
               ylimBotMod = 1,         # modify ylim bottom argument
               xlimRightMod = 0        # modify xlim right argument
+              ,asp=1                  # y x aspect
 )
 
 ## ------------------------------------------------------------------------
@@ -113,30 +106,20 @@ plotIdiograms(dfChrSize=dfwithHetero,    # chr sizes
               cenColor = "gray",         # colors of centromeres
               
               chrId="original",          # chr. name in df.
-              indexIdTextSize=1,         # font size of chr. name and indices
               chrIndex = FALSE,          # do not add chr. indices
               morpho=FALSE,              # do not add chr. morphologies  
               karIndex = FALSE,          # do not add karyotype indices
+              distTextChr = .8,          # distance from text to chr.
               
-              dotRoundCorr=2,            # correction factor of roundness of dots
-              markLabelSize=1,           # font size of legends
-              MarkDistanceType="cen",    # mark distance is to center of mark
-              
-              chrWidth=2.5,              # chr. width
-              chrSpacing = 2.5,          # space among chr.
+              markDistType="cen",        # mark position measured to center of mark
               orderBySize = FALSE,       # do not order chr. by size
-              karHeiSpace=1.2,           # vertical size of karyotypes including spacing
               
-              rulerPos=-1.9,             # position of rulers
-              ruler.tck=-0.02,           # size and orientation of ticks of ruler
-              rulerNumberPos=.5,         # position of numbers of ruler
-              rulerNumberSize=1,         # font size of ruler numbers
+              rulerPos=-.5,              # position of rulers
+              ruler.tck=-0.01,           # size and orientation of ticks of ruler
               
-              ylimBotMod = -.2,          # modify ylim bottom argument
-              xlimRightMod = 7           # modify xlim right argument
-              , legend="aside"
-              , markLabelSpacer = 2
-              , legendWidth = 1
+              ylimBotMod = .2            # modify ylim bottom argument
+              , legendWidth = 1          # width of legend
+              , asp =1                   # y x aspect of plot
 )
 dev.off()
 
@@ -159,29 +142,18 @@ dfChrSizeHoloHetero$group<-c(1,1,NA,NA)
 plotIdiograms(dfChrSize=dfChrSizeHoloHetero, # df of chr sizes
               orderBySize = FALSE,           # do not order chr. by size
               dfMarkPos=dfMarkPosHoloHetero, # df of position of marks
-              dotRoundCorr=3,                # correction of roundness of dots
               
-              chrWidth = 2.3,                # chr. width
-              chrSpacing = 2,                # chr. spacing
               karIndex = FALSE,              # do not add karyotype asymmetry index
-              indexIdTextSize=1,             # font size of chr. name and indices
-              karHeight = 1.4,               # vertical size of karyotypes
               addOTUName=FALSE,              # do not add name of OTUs
-              distTextChr = 0.6,             # distance from chr. to its name
               
-              legend="aside",                # position of legend to the right
-              markLabelSize=1,               # font size of legend
-              markLabelSpacer=4,             # space among chr. and legend
-              
-              rulerNumberSize=1,             # font size of ruler
-              rulerPos=-2.2,                 # position of ruler
+              rulerPos=-.5,                  # position of ruler
               ruler.tck=-0.03,               # size and orientation of ticks
               rulerNumberPos=.9,             # position of rulers' numbers
               
-              xlimLeftMod=2.2,               # modify left argument of xlim
-              xlimRightMod=15,               # modify right argument of xlim
+              xlimLeftMod=0,                 # modify left argument of xlim
               ylimBotMod=.3                  # modifiy bottom argument of ylim
               ,legendWidth=1                 # width of legend
+              ,asp=1                         # y x aspect
 )
 
 ## ------------------------------------------------------------------------
@@ -199,20 +171,14 @@ kableExtra::kable_styling(knitr::kable(dfChrSizeHoloGroup) , full_width = F
 plotIdiograms(dfChrSize=dfChrSizeHoloGroup, # data.frame of chr sizes
               orderBySize = FALSE,          # do not order chr. by size
               karIndex = FALSE,             # do not add karyotype indices
-              chrWidth = 2,                 # chr. width
-              chrSpacing = 2,               # space among chr.
-              indexIdTextSize=1,            # font size of chr. names and indices
-              OTUTextSize=1,                # font size of OTU names
-              karHeight = 1.4,              # karyotype rel. height
-              distTextChr = 0.6,            # distance from chr. to its name
               
-              rulerNumberSize=1,            # font size of ruler
-              rulerPos=-2.2,                # position of ruler
+              rulerPos=-.5,                 # position of ruler
               ruler.tck=-0.03,              # size and orientation of ticks of ruler
               rulerNumberPos=.9,            # position of number of ruler
               
-              xlimLeftMod=2.2,              # modify left argument of xlim
-              xlimRightMod=10,              # modify right argument of xlim
+              xlimLeftMod=0,                # modify left argument of xlim
+              xlimRightMod=0,               # modify right argument of xlim
               ylimBotMod=.3                 # modify bottom argument of ylim
+              ,asp =1                       # y x aspect
 )
 
